@@ -1,46 +1,30 @@
-# -*- coding: utf-8 -*-
+# SPDX-License-Identifier: GPL-2.0-or-later
 #
 # Copyright (C) 2011-2016 Red Hat, Inc.
 #
 # Authors:
 # Thomas Woerner <twoerner@redhat.com>
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
 
 """ifcfg file parser"""
 
-__all__ = [ "ifcfg" ]
-
 import os.path
 import io
 import tempfile
 import shutil
 
 from firewall.core.logger import log
-from firewall.functions import b2u, u2b, PY2
 
-class ifcfg(object):
+
+class ifcfg:
     def __init__(self, filename):
-        self._config = { }
-        self._deleted = [ ]
+        self._config = {}
+        self._deleted = []
         self.filename = filename
         self.clear()
 
     def clear(self):
-        self._config = { }
-        self._deleted = [ ]
+        self._config = {}
+        self._deleted = []
 
     def cleanup(self):
         self._config.clear()
@@ -49,18 +33,18 @@ class ifcfg(object):
         return self._config.get(key.strip())
 
     def set(self, key, value):
-        _key = b2u(key.strip())
-        self._config[_key] = b2u(value.strip())
+        _key = key.strip()
+        self._config[_key] = value.strip()
         if _key in self._deleted:
             self._deleted.remove(_key)
 
     def __str__(self):
         s = ""
-        for (key, value) in self._config.items():
+        for key, value in self._config.items():
             if s:
-                s += '\n'
-            s += '%s=%s' % (key, value)
-        return u2b(s) if PY2 else s
+                s += "\n"
+            s += "%s=%s" % (key, value)
+        return s
 
     # load self.filename
     def read(self):
@@ -75,19 +59,20 @@ class ifcfg(object):
             if not line:
                 break
             line = line.strip()
-            if len(line) < 1 or line[0] in ['#', ';']:
+            if len(line) < 1 or line[0] in ["#", ";"]:
                 continue
             # get key/value pair
-            pair = [ x.strip() for x in line.split("=", 1) ]
+            pair = [x.strip() for x in line.split("=", 1)]
             if len(pair) != 2:
                 continue
-            if len(pair[1]) >= 2 and \
-               pair[1].startswith('"') and pair[1].endswith('"'):
+            if len(pair[1]) >= 2 and pair[1].startswith('"') and pair[1].endswith('"'):
                 pair[1] = pair[1][1:-1]
-            if pair[1] == '':
+            if pair[1] == "":
                 continue
             elif self._config.get(pair[0]) is not None:
-                log.warning("%s: Duplicate option definition: '%s'", self.filename, line.strip())
+                log.warning(
+                    "%s: Duplicate option definition: '%s'", self.filename, line.strip()
+                )
                 continue
             self._config[pair[0]] = pair[1]
         f.close()
@@ -98,16 +83,15 @@ class ifcfg(object):
             return
 
         # handled keys
-        done = [ ]
-
-        #if not os.path.exists(ETC_FIREWALLD):
-        #    os.mkdir(ETC_FIREWALLD, 0o750)
+        done = []
 
         try:
             temp_file = tempfile.NamedTemporaryFile(
-                mode='wt',
+                mode="wt",
                 prefix="%s." % os.path.basename(self.filename),
-                dir=os.path.dirname(self.filename), delete=False)
+                dir=os.path.dirname(self.filename),
+                delete=False,
+            )
         except Exception as msg:
             log.error("Failed to open temporary file: %s" % msg)
             raise
@@ -115,7 +99,7 @@ class ifcfg(object):
         modified = False
         empty = False
         try:
-            f = io.open(self.filename, mode='rt', encoding='UTF-8')
+            f = io.open(self.filename, mode="rt", encoding="UTF-8")
         except Exception as msg:
             if os.path.exists(self.filename):
                 log.error("Failed to open '%s': %s" % (self.filename, msg))
@@ -131,54 +115,56 @@ class ifcfg(object):
 
                 if len(line) < 1:
                     if not empty:
-                        temp_file.write(u"\n")
+                        temp_file.write("\n")
                         empty = True
-                elif line[0] == '#':
+                elif line[0] == "#":
                     empty = False
                     temp_file.write(line)
-                    temp_file.write(u"\n")
+                    temp_file.write("\n")
                 else:
                     p = line.split("=", 1)
                     if len(p) != 2:
                         empty = False
-                        temp_file.write(line+u"\n")
+                        temp_file.write(line + "\n")
                         continue
                     key = p[0].strip()
                     value = p[1].strip()
-                    if len(value) >= 2 and \
-                       value.startswith('"') and value.endswith('"'):
+                    if (
+                        len(value) >= 2
+                        and value.startswith('"')
+                        and value.endswith('"')
+                    ):
                         value = value[1:-1]
                     # check for modified key/value pairs
                     if key not in done:
                         if key in self._config and self._config[key] != value:
                             empty = False
-                            temp_file.write(u'%s=%s\n' % (key,
-                                                          self._config[key]))
+                            temp_file.write("%s=%s\n" % (key, self._config[key]))
                             modified = True
                         elif key in self._deleted:
                             modified = True
                         else:
                             empty = False
-                            temp_file.write(line+u"\n")
+                            temp_file.write(line + "\n")
                         done.append(key)
                     else:
                         modified = True
 
         # write remaining key/value pairs
         if len(self._config) > 0:
-            for (key, value) in self._config.items():
+            for key, value in self._config.items():
                 if key in done:
                     continue
                 if not empty:
                     empty = True
-                temp_file.write(u'%s=%s\n' % (key, value))
+                temp_file.write("%s=%s\n" % (key, value))
                 modified = True
 
         if f:
             f.close()
         temp_file.close()
 
-        if not modified: # not modified: remove tempfile
+        if not modified:  # not modified: remove tempfile
             os.remove(temp_file.name)
             return
         # make backup
