@@ -785,6 +785,7 @@ class Policy(IO_Object):
         "priority": 0,  # i
         "ingress_zones": [""],  # as
         "egress_zones": [""],  # as
+        "disable": False,  # b
     }
     ADDITIONAL_ALNUM_CHARS = ["_", "-", "/"]
     PARSER_REQUIRED_ELEMENT_ATTRS = {
@@ -812,6 +813,7 @@ class Policy(IO_Object):
         "limit": ["value"],
         "ingress-zone": ["name"],
         "egress-zone": ["name"],
+        "disable": None,
     }
     PARSER_OPTIONAL_ELEMENT_ATTRS = {
         "policy": ["version", "priority"],
@@ -846,6 +848,7 @@ class Policy(IO_Object):
         self.derived_from_zone = None
         self.ingress_zones = []
         self.egress_zones = []
+        self.disable = False
 
     def cleanup(self):
         self.version = ""
@@ -865,6 +868,7 @@ class Policy(IO_Object):
         self.priority = self.priority_default
         del self.ingress_zones[:]
         del self.egress_zones[:]
+        self.disable = False
 
     def __getattr__(self, name):
         if name == "rich_rules":
@@ -1194,6 +1198,9 @@ class policy_ContentHandler(IO_Object_ContentHandler):
             )
             return
 
+        elif name == "disable":
+            self.item.disable = True
+
         else:
             raise FirewallError(errors.INVALID_POLICY, f"Unknown XML element '{name}'.")
 
@@ -1283,6 +1290,11 @@ def policy_writer(policy, path=None):
         handler.simpleElement("egress-zone", {"name": zone})
         handler.ignorableWhitespace("\n")
 
+    if policy.disable:
+        handler.ignorableWhitespace("  ")
+        handler.simpleElement("disable", {})
+        handler.ignorableWhitespace("\n")
+
     # end policy element
     handler.endElement("policy")
     handler.ignorableWhitespace("\n")
